##
##  openfst.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2019 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         openfst
Summary:      Finite State Transducer Library
URL:          http://template.example.com/
Vendor:       Cyril Allauzen, Michael Riley
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Algorithm
License:      Apache
Version:      1.7.2
Release:      20190412

#   list of sources
Source0:      http://www.openfst.org/twiki/pub/FST/FstDownload/openfst-%{version}.tar.gz
Patch0:       openfst.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101

%description
    OpenFST is a library for constructing, combining, optimizing,
    and searching weighted finite-state transducers (FSTs). Weighted
    finite-state transducers are automata where each transition has
    an input label, an output label, and a weight. The more familiar
    finite-state acceptor is represented as a transducer with each
    transition's input and output label equal. Finite-state acceptors
    are used to represent sets of strings (specifically, regular or
    rational sets); finite-state transducers are used to represent
    binary relations between pairs of strings (specifically, rational
    transductions). The weights can be used to represent the cost of
    taking a particular transition.

%track
    prog openfst = {
        version   = %{version}
        url       = http://www.openfst.org/twiki/bin/view/FST/FstDownload
        regex     = openfst-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    case "%{l_platform -t}" in
        linux* ) ;;
        * )
            %{l_shtool} subst \
                -e 's;-ldl;;g' \
                `find . -name "Makefile.in" -type f -print`
            ;;
    esac
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --disable-shared \
        --enable-bin
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

